--[[
LuCI - Lua Configuration Interface
]]--

local taskd = require "luci.model.tasks"
local filebrowser_model = require "luci.model.filebrowser"
local m, s, o

m = taskd.docker_map("filebrowser", "filebrowser", "/usr/libexec/apps/filebrowser/filebrowser.sh",
	translate("Filebrowser"),
	translate("FileBrowser provides a file managing interface within a specified directory and it can be used to upload, delete, preview, rename and edit your files.")
		.. translate("Official website:") .. ' <a href=\"https://filebrowser.org/\" target=\"_blank\">https://filebrowser.org/</a>')

s = m:section(SimpleSection, translate("Service Status"), translate("Filebrowser status:"))
s:append(Template("filebrowser/status"))

s = m:section(TypedSection, "filebrowser", translate("Setup"), translate("Default user: admin Default pass: admin"))
s.addremove=false
s.anonymous=true

o = s:option(Value, "port", translate("Port").."<b>*</b>")
o.rmempty = false
o.default = "8984"
o.datatype = "port"

o = s:option(Value, "image_name", translate("Image").."<b>*</b>")
o.rmempty = false
o.datatype = "string"
o:value("hurlenko/filebrowser", "hurlenko/filebrowser")
o.default = "hurlenko/filebrowser"

local blocks = filebrowser_model.blocks()
local home = filebrowser_model.home()

o = s:option(Value, "config_path", translate("Data path").."<b>*</b>")
o.rmempty = false
o.datatype = "string"
o:value("/opt/docker2/compose", "/opt/docker2/compose")
o.default = "/opt/docker2/compose"

local paths, default_path = filebrowser_model.find_paths(blocks, home, "Configs")
for _, val in pairs(paths) do
  o:value(val, val)
end
o.default = default_path

return m
